﻿//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  Boardmodul: Bereitstellung gerätespezifischer Funktionen und Mechanismen            //
//  _________________________________                                                   //
//                                                                                      //
//  Copyright (c) 2019 Reimar Grasbon                                                   //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  This software is subjected to the FreeBSD License. Redistribution and use in source //
//  and binary forms, with or without modification, are permitted provided that the     //
//  following conditions are met:                                                       //
//                                                                                      //
//  1. Redistributions of source code must retain the above copyright notice, this list //
//     of conditions and the following disclaimer.                                      //
//                                                                                      //
//  2. Redistributions in binary form must reproduce the above copyright notice, this   //
//     list of conditions and the following disclaimer in the documentation and/or      //
//     other materials provided with the distribution.                                  //
//                                                                                      //
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY //
//  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED           //
//  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  //
//  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,    //
//  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT  //
//  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR  //
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,   //
//  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)  //
//  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE          //
//  POSSIBILITY OF SUCH DAMAGE.                                                         //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include "Conf.h"
#include "TypeDefs.h"
#include "DateTime.h"

//////////////////////////////////////////////////////////////////////////////////////////
//  Typen  ///////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
typedef enum
{   LED_SWITCH_1 = 0,
	LED_SWITCH_2 = 1,
    LED_INFO	 = 2
} Led;

typedef enum
{   POWER_SWITCH_1 = 0,
	POWER_SWITCH_2 = 1
} PowerSwitch;

//////////////////////////////////////////////////////////////////////////////////////////
//  Funktionen  //////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
void    BOARD_Reset(void);
void    BOARD_EnterPgmLdr(void);
UInt16  BOARD_MSecTicks(void);
UInt16  BOARD_SecTicks(void);
void    BOARD_EEPLoad(const void*, void*, UInt16);
void    BOARD_EEPSave(const void*, void*, UInt16);
bool    BOARD_I2cTransmit(SInt08, const UInt08*, UInt08);
bool    BOARD_I2cReceive(SInt08, UInt08*, UInt08);
bool    BOARD_I2cTransceive(SInt08, const UInt08*, UInt08, UInt08*, UInt08);
void    BOARD_SetClock(const DateTime*);
void    BOARD_Clock(DateTime*);
bool    BOARD_BusIsIdle(void);
void    BOARD_BusTransmit(UInt08);
bool    BOARD_BusIsTransmitting(void);
bool    BOARD_BusTakeFailure(void);
bool    BOARD_BusReceive(UInt08*);
bool    BOARD_BusIsReceiving(void);
void    BOARD_BusOnActivity(void);
bool    BOARD_BusActivity(void);
void    BOARD_SetLed(Led, bool);
bool    BOARD_Led(Led);
void    BOARD_SetPowerSwitch(PowerSwitch, bool);
bool    BOARD_PowerSwitch(PowerSwitch);

//////////////////////////////////////////////////////////////////////////////////////////
//  Prozessaufrufe  //////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
void    BOARD_Startup(void);
bool    BOARD_DoMainLoop(void);
void    BOARD_Proceed(void);
void    BOARD_Shutdown(void);

//////////////////////////////////////////////////////////////////////////////////////////
